Documentation
¶
Index ¶
- type Box
- type DCMIType
- type DDC
- type ElementOrRefinementContainer
- func (m *ElementOrRefinementContainer) MarshalXML(e *xml.Encoder, start xml.StartElement) error
- func (m *ElementOrRefinementContainer) UnmarshalXML(d *xml.Decoder, start xml.StartElement) error
- func (m *ElementOrRefinementContainer) Validate() error
- func (m *ElementOrRefinementContainer) ValidateWithPath(path string) error
- type ElementsAndRefinementsGroup
- func (m *ElementsAndRefinementsGroup) MarshalXML(e *xml.Encoder, start xml.StartElement) error
- func (m *ElementsAndRefinementsGroup) UnmarshalXML(d *xml.Decoder, start xml.StartElement) error
- func (m *ElementsAndRefinementsGroup) Validate() error
- func (m *ElementsAndRefinementsGroup) ValidateWithPath(path string) error
- type ElementsAndRefinementsGroupChoice
- func (m *ElementsAndRefinementsGroupChoice) MarshalXML(e *xml.Encoder, start xml.StartElement) error
- func (m *ElementsAndRefinementsGroupChoice) UnmarshalXML(d *xml.Decoder, start xml.StartElement) error
- func (m *ElementsAndRefinementsGroupChoice) Validate() error
- func (m *ElementsAndRefinementsGroupChoice) ValidateWithPath(path string) error
- type IMT
- type ISO3166
- type ISO639_2
- type LCC
- type LCSH
- type MESH
- type Period
- type Point
- type RFC1766
- type RFC3066
- type TGN
- type UDC
- type URI
- type W3CDTF
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Box ¶
type Box struct {
}
type DCMIType ¶
type DCMIType struct {
}
func (*DCMIType) MarshalXML ¶
func (*DCMIType) UnmarshalXML ¶
func (*DCMIType) Validate ¶
Validate validates the DCMIType and its children
type DDC ¶
type DDC struct {
}
type ElementOrRefinementContainer ¶
type ElementOrRefinementContainer struct {
Choice []*ElementsAndRefinementsGroupChoice
}
func NewElementOrRefinementContainer ¶
func NewElementOrRefinementContainer() *ElementOrRefinementContainer
func (*ElementOrRefinementContainer) MarshalXML ¶
func (m *ElementOrRefinementContainer) MarshalXML(e *xml.Encoder, start xml.StartElement) error
func (*ElementOrRefinementContainer) UnmarshalXML ¶
func (m *ElementOrRefinementContainer) UnmarshalXML(d *xml.Decoder, start xml.StartElement) error
func (*ElementOrRefinementContainer) Validate ¶
func (m *ElementOrRefinementContainer) Validate() error
Validate validates the ElementOrRefinementContainer and its children
func (*ElementOrRefinementContainer) ValidateWithPath ¶
func (m *ElementOrRefinementContainer) ValidateWithPath(path string) error
ValidateWithPath validates the ElementOrRefinementContainer and its children, prefixing error messages with path
type ElementsAndRefinementsGroup ¶
type ElementsAndRefinementsGroup struct {
Choice []*ElementsAndRefinementsGroupChoice
}
func NewElementsAndRefinementsGroup ¶
func NewElementsAndRefinementsGroup() *ElementsAndRefinementsGroup
func (*ElementsAndRefinementsGroup) MarshalXML ¶
func (m *ElementsAndRefinementsGroup) MarshalXML(e *xml.Encoder, start xml.StartElement) error
func (*ElementsAndRefinementsGroup) UnmarshalXML ¶
func (m *ElementsAndRefinementsGroup) UnmarshalXML(d *xml.Decoder, start xml.StartElement) error
func (*ElementsAndRefinementsGroup) Validate ¶
func (m *ElementsAndRefinementsGroup) Validate() error
Validate validates the ElementsAndRefinementsGroup and its children
func (*ElementsAndRefinementsGroup) ValidateWithPath ¶
func (m *ElementsAndRefinementsGroup) ValidateWithPath(path string) error
ValidateWithPath validates the ElementsAndRefinementsGroup and its children, prefixing error messages with path
type ElementsAndRefinementsGroupChoice ¶
func NewElementsAndRefinementsGroupChoice ¶
func NewElementsAndRefinementsGroupChoice() *ElementsAndRefinementsGroupChoice
func (*ElementsAndRefinementsGroupChoice) MarshalXML ¶
func (m *ElementsAndRefinementsGroupChoice) MarshalXML(e *xml.Encoder, start xml.StartElement) error
func (*ElementsAndRefinementsGroupChoice) UnmarshalXML ¶
func (m *ElementsAndRefinementsGroupChoice) UnmarshalXML(d *xml.Decoder, start xml.StartElement) error
func (*ElementsAndRefinementsGroupChoice) Validate ¶
func (m *ElementsAndRefinementsGroupChoice) Validate() error
Validate validates the ElementsAndRefinementsGroupChoice and its children
func (*ElementsAndRefinementsGroupChoice) ValidateWithPath ¶
func (m *ElementsAndRefinementsGroupChoice) ValidateWithPath(path string) error
ValidateWithPath validates the ElementsAndRefinementsGroupChoice and its children, prefixing error messages with path
type IMT ¶
type IMT struct {
}
type ISO3166 ¶
type ISO3166 struct {
}
func (*ISO3166) MarshalXML ¶
func (*ISO3166) UnmarshalXML ¶
func (*ISO3166) Validate ¶
Validate validates the ISO3166 and its children
type ISO639_2 ¶
type ISO639_2 struct {
}
func (*ISO639_2) MarshalXML ¶
func (*ISO639_2) UnmarshalXML ¶
func (*ISO639_2) Validate ¶
Validate validates the ISO639_2 and its children
type LCC ¶
type LCC struct {
}
type LCSH ¶
type LCSH struct {
}
func (*LCSH) UnmarshalXML ¶
func (*LCSH) Validate ¶
Validate validates the LCSH and its children
type MESH ¶
type MESH struct {
}
func (*MESH) UnmarshalXML ¶
func (*MESH) Validate ¶
Validate validates the MESH and its children
type Period ¶
type Period struct {
}
func (*Period) MarshalXML ¶
func (*Period) UnmarshalXML ¶
func (*Period) Validate ¶
Validate validates the Period and its children
type Point ¶
type Point struct {
}
func (*Point) UnmarshalXML ¶
func (*Point) Validate ¶
Validate validates the Point and its children
type RFC1766 ¶
type RFC1766 struct {
}
func (*RFC1766) MarshalXML ¶
func (*RFC1766) UnmarshalXML ¶
func (*RFC1766) Validate ¶
Validate validates the RFC1766 and its children
type RFC3066 ¶
type RFC3066 struct {
}
func (*RFC3066) MarshalXML ¶
func (*RFC3066) UnmarshalXML ¶
func (*RFC3066) Validate ¶
Validate validates the RFC3066 and its children
type TGN ¶
type TGN struct {
}
type UDC ¶
type UDC struct {
}
type URI ¶
type URI struct {
}
Source Files
¶
- Box.go
- DCMIType.go
- DDC.go
- ElementOrRefinementContainer.go
- ElementsAndRefinementsGroup.go
- ElementsAndRefinementsGroupChoice.go
- IMT.go
- ISO3166.go
- ISO639_2.go
- LCC.go
- LCSH.go
- MESH.go
- Period.go
- Point.go
- RFC1766.go
- RFC3066.go
- TGN.go
- UDC.go
- URI.go
- W3CDTF.go
- common.go